@@ -13,7 +13,7 @@
 ;;; GNU General Public License for more details.
 
 ;;; You should have received a copy of the GNU General Public License
-;;; along with this program.  If not, see <http://www.gnu.org/licenses/>.
+;;; along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 (in-package :consfigurator.property.cron)
 (named-readtables:in-readtable :consfigurator)
@@ -21,10 +21,10 @@
 ;;; A number of techniques here are from Propellor's Cron properties module.
 
 (defpropspec system-job :posix (desc when user shell-command)
-  "Installs a cronjob running SHELL-COMMAND as USER to /etc/cron.*.
+  "Installs a cronjob running SHELL-COMMAND as USER to ``/etc/cron.*``.
 DESC must be unique, as it will be used as a filename for a script.  WHEN is
 either :DAILY, WEEKLY, :MONTHLY or a string formatted according to crontab(5),
-e.g. \"0 3 * * *\".
+e.g. ``0 3 * * *``.
 
 The output of the cronjob will be mailed only if the job exits nonzero."
   (:desc #?"Cronned ${desc}")
@@ -135,7 +135,7 @@ directory."
           (old (runlines :may-fail "crontab" "-l"))
           (new
             (mapcar
-             (lambda (line) (re:regex-replace-all #?/\$HOME/ line home))
+             #~s/\$HOME/${home}/g
              (nconc
               (list "# Automatically updated by Consfigurator; do not edit" "")
               (loop for (k v) on env by #'cddr
